# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litecms/concern/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Litecms\\Concern\\": "packages/litecms/concern/src",
            "Litecms\\Concern\\Seeders\\": "packages/litecms/concern/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litecms\Concern\Providers\ConcernServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Concern'  => Litecms\Concern\Facades\Concern::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litecms\\Concern\\Seeders\\ConcernTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litecms\Concern\Providers\ConcernServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litecms\Concern\Providers\ConcernServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litecms\Concern\Providers\ConcernServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/concern/{modulename}

**User**

    http://path-to-route-folder/user/concern/{modulename}

**Public**

    http://path-to-route-folder/concerns


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/concern/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/concern/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/concern/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/concern/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/concern/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/concern/{modulename}/{slug}
    METHOD: GET