<?php

namespace Litecms\Concern\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Litecms\Concern\Interfaces\ConcernRepositoryInterface;
use Litecms\Concern\Repositories\Eloquent\Filters\ConcernPublicFilter;
use Litecms\Concern\Repositories\Eloquent\Presenters\ConcernListPresenter;

class ConcernPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        ConcernRepositoryInterface $concern
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('litecms.concern.modules'), 'concern', guard_url('concern'));
        $this->repository = $concern;
    }

    /**
     * Show concern's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(ConcernPublicFilter::class)
            ->setPresenter(ConcernListPresenter::class)
            ->select('concerns.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('concern::concern.names'))
            ->view('concern::public.concern.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show concern.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('concern::concern.name'))
            ->view('concern::public.concern.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
