<?php

namespace Litecms\Concern\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Litecms\Concern\Http\Requests\ConcernRequest;
use Litecms\Concern\Models\Concern;

/**
 * Admin web controller class.
 */
class ConcernWorkflowController extends BaseController
{

    /**
     * Workflow controller function for concern.
     *
     * @param Model   $concern
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ConcernRequest $request, Concern $concern, $step)
    {

        try {

            $concern->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('concern::concern.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/concern/concern/' . $concern->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/concern/concern/' . $concern->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for concern.
     *
     * @param Model   $concern
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Concern $concern, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $concern->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('concern::concern.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('concern::admin.concern.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('concern::admin.concern.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('concern::admin.concern.message', $data)->render();

        }

    }
}
