<?php

namespace Litecms\Concern\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Litecms\Concern\Models\Concern;

class ConcernAction
{
    /**
     * Perform the complete action.
     *
     * @param Concern $concern
     *
     * @return Concern
     */
    public function complete(Concern $concern)
    {
        try {
            $concern->status = 'complete';
            return $concern->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Concern $concern
     *
     * @return Concern
     */public function verify(Concern $concern)
    {
        try {
            $concern->status = 'verify';
            return $concern->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Concern $concern
     *
     * @return Concern
     */public function approve(Concern $concern)
    {
        try {
            $concern->status = 'approve';
            return $concern->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Concern $concern
     *
     * @return Concern
     */public function publish(Concern $concern)
    {
        try {
            $concern->status = 'publish';
            return $concern->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Concern $concern
     *
     * @return Concern
     */
    public function archive(Concern $concern)
    {
        try {
            $concern->status = 'archive';
            return $concern->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Concern $concern
     *
     * @return Concern
     */
    public function unpublish(Concern $concern)
    {
        try {
            $concern->status = 'unpublish';
            return $concern->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
