<?php

namespace Litecms\Concern\Workflow;

use Litecms\Concern\Models\Concern;
use Validator;

class ConcernValidator
{

    /**
     * Determine if the given concern is valid for complete status.
     *
     * @param Concern $concern
     *
     * @return bool / Validator
     */
    public function complete(Concern $concern)
    {
        return Validator::make($concern->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given concern is valid for verify status.
     *
     * @param Concern $concern
     *
     * @return bool / Validator
     */
    public function verify(Concern $concern)
    {
        return Validator::make($concern->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given concern is valid for approve status.
     *
     * @param Concern $concern
     *
     * @return bool / Validator
     */
    public function approve(Concern $concern)
    {
        return Validator::make($concern->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given concern is valid for publish status.
     *
     * @param Concern $concern
     *
     * @return bool / Validator
     */
    public function publish(Concern $concern)
    {
        return Validator::make($concern->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given concern is valid for archive status.
     *
     * @param Concern $concern
     *
     * @return bool / Validator
     */
    public function archive(Concern $concern)
    {
        return Validator::make($concern->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given concern is valid for unpublish status.
     *
     * @param Concern $concern
     *
     * @return bool / Validator
     */
    public function unpublish(Concern $concern)
    {
        return Validator::make($concern->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
